# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_age_distribution_data import ReportingAgeDistributionData
from neurograph.v1.models.reporting_demographics_meta import ReportingDemographicsMeta
from neurograph.v1.models.reporting_gender_split_data import ReportingGenderSplitData
from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData
from neurograph.v1.models.reporting_income_bands_data import ReportingIncomeBandsData
from typing import Optional, Set
from typing_extensions import Self

class ReportingPersonaDemographicsResponse(BaseModel):
    """
    ReportingPersonaDemographicsResponse
    """ # noqa: E501
    age_distribution: Optional[ReportingAgeDistributionData] = None
    cached: Optional[StrictBool] = None
    error: Optional[StrictStr] = None
    gender_split: Optional[ReportingGenderSplitData] = None
    geographic_distribution: Optional[ReportingGeographicDistributionData] = None
    income_bands: Optional[ReportingIncomeBandsData] = None
    meta: Optional[ReportingDemographicsMeta] = None
    query_time_ms: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["age_distribution", "cached", "error", "gender_split", "geographic_distribution", "income_bands", "meta", "query_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingPersonaDemographicsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of age_distribution
        if self.age_distribution:
            _dict['age_distribution'] = self.age_distribution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gender_split
        if self.gender_split:
            _dict['gender_split'] = self.gender_split.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geographic_distribution
        if self.geographic_distribution:
            _dict['geographic_distribution'] = self.geographic_distribution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of income_bands
        if self.income_bands:
            _dict['income_bands'] = self.income_bands.to_dict()
        # override the default output from pydantic by calling `to_dict()` of meta
        if self.meta:
            _dict['meta'] = self.meta.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingPersonaDemographicsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "age_distribution": ReportingAgeDistributionData.from_dict(obj["age_distribution"]) if obj.get("age_distribution") is not None else None,
            "cached": obj.get("cached"),
            "error": obj.get("error"),
            "gender_split": ReportingGenderSplitData.from_dict(obj["gender_split"]) if obj.get("gender_split") is not None else None,
            "geographic_distribution": ReportingGeographicDistributionData.from_dict(obj["geographic_distribution"]) if obj.get("geographic_distribution") is not None else None,
            "income_bands": ReportingIncomeBandsData.from_dict(obj["income_bands"]) if obj.get("income_bands") is not None else None,
            "meta": ReportingDemographicsMeta.from_dict(obj["meta"]) if obj.get("meta") is not None else None,
            "query_time_ms": obj.get("query_time_ms")
        })
        return _obj


