# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OrganizationsGammaCardSettings(BaseModel):
    """
    OrganizationsGammaCardSettings
    """ # noqa: E501
    accent_image_shape: Optional[StrictInt] = Field(default=None, description="0-7 (various shapes)")
    card_border: Optional[StrictInt] = Field(default=None, description="0-3 scale (none, thin, medium, thick)")
    card_border_color: Optional[StrictStr] = None
    card_shadow: Optional[StrictInt] = Field(default=None, description="0-2 scale (none, subtle, strong)")
    card_transparency: Optional[StrictInt] = Field(default=None, description="0-2 scale (solid, semi, transparent)")
    roundness: Optional[StrictInt] = Field(default=None, description="0-4 scale (0=square, 4=most rounded)")
    __properties: ClassVar[List[str]] = ["accent_image_shape", "card_border", "card_border_color", "card_shadow", "card_transparency", "roundness"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationsGammaCardSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationsGammaCardSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accent_image_shape": obj.get("accent_image_shape"),
            "card_border": obj.get("card_border"),
            "card_border_color": obj.get("card_border_color"),
            "card_shadow": obj.get("card_shadow"),
            "card_transparency": obj.get("card_transparency"),
            "roundness": obj.get("roundness")
        })
        return _obj


