# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OrganizationsGammaThemeRequest(BaseModel):
    """
    OrganizationsGammaThemeRequest
    """ # noqa: E501
    accent_color: Optional[StrictStr] = None
    background_color: Optional[StrictStr] = None
    border_color: Optional[StrictStr] = None
    brand_personality: Optional[StrictStr] = None
    brand_reasoning: Optional[StrictStr] = Field(default=None, description="Brand analysis context from AI branding generation")
    brand_style: Optional[StrictStr] = None
    industry: Optional[StrictStr] = Field(default=None, description="Optional context")
    primary_color: Optional[StrictStr] = Field(default=None, description="Core brand colors")
    secondary_color: Optional[StrictStr] = None
    source_url: Optional[StrictStr] = None
    surface_color: Optional[StrictStr] = None
    target_audience: Optional[StrictStr] = None
    text_color: Optional[StrictStr] = None
    text_secondary_color: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["accent_color", "background_color", "border_color", "brand_personality", "brand_reasoning", "brand_style", "industry", "primary_color", "secondary_color", "source_url", "surface_color", "target_audience", "text_color", "text_secondary_color"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationsGammaThemeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationsGammaThemeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accent_color": obj.get("accent_color"),
            "background_color": obj.get("background_color"),
            "border_color": obj.get("border_color"),
            "brand_personality": obj.get("brand_personality"),
            "brand_reasoning": obj.get("brand_reasoning"),
            "brand_style": obj.get("brand_style"),
            "industry": obj.get("industry"),
            "primary_color": obj.get("primary_color"),
            "secondary_color": obj.get("secondary_color"),
            "source_url": obj.get("source_url"),
            "surface_color": obj.get("surface_color"),
            "target_audience": obj.get("target_audience"),
            "text_color": obj.get("text_color"),
            "text_secondary_color": obj.get("text_secondary_color")
        })
        return _obj


