# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_daily_client_pixel_metrics import PixelDailyClientPixelMetrics

class TestPixelDailyClientPixelMetrics(unittest.TestCase):
    """PixelDailyClientPixelMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelDailyClientPixelMetrics:
        """Test PixelDailyClientPixelMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelDailyClientPixelMetrics`
        """
        model = PixelDailyClientPixelMetrics()
        if include_optional:
            return PixelDailyClientPixelMetrics(
                avg_match_confidence = 1.337,
                avg_session_duration = 1.337,
                daily_cost = 1.337,
                var_date = '',
                enriched_visitors = 56,
                enrichment_rate_pct = 1.337,
                match_rate_pct = 1.337,
                matched_hems = 56,
                temporal_matches = 56,
                total_pageviews = 56,
                total_sessions = 56,
                unique_visitors = 56,
                vendor_matches = 56
            )
        else:
            return PixelDailyClientPixelMetrics(
        )
        """

    def testPixelDailyClientPixelMetrics(self):
        """Test PixelDailyClientPixelMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
