# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_product_performance_data import ReportingProductPerformanceData

class TestReportingProductPerformanceData(unittest.TestCase):
    """ReportingProductPerformanceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingProductPerformanceData:
        """Test ReportingProductPerformanceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingProductPerformanceData`
        """
        model = ReportingProductPerformanceData()
        if include_optional:
            return ReportingProductPerformanceData(
                products = [
                    neurograph.v1.models.reporting/product_performance_row.reporting.ProductPerformanceRow(
                        affinity_score = 1.337, 
                        affinity_tier = '', 
                        avg_spend = 1.337, 
                        conversion_rate = 1.337, 
                        engagement_score = 1.337, 
                        product_handle = '', 
                        product_name = '', 
                        product_type = '', 
                        purchases = 56, )
                    ],
                total_products = 56
            )
        else:
            return ReportingProductPerformanceData(
        )
        """

    def testReportingProductPerformanceData(self):
        """Test ReportingProductPerformanceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
