# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_purchase_timing_data import ReportingPurchaseTimingData

class TestReportingPurchaseTimingData(unittest.TestCase):
    """ReportingPurchaseTimingData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPurchaseTimingData:
        """Test ReportingPurchaseTimingData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPurchaseTimingData`
        """
        model = ReportingPurchaseTimingData()
        if include_optional:
            return ReportingPurchaseTimingData(
                peak_shopping_time = '',
                timing_distribution = [
                    neurograph.v1.models.reporting/timing_bucket.reporting.TimingBucket(
                        is_peak = True, 
                        order_count = 56, 
                        percentage = 1.337, 
                        timing_bucket = '', )
                    ]
            )
        else:
            return ReportingPurchaseTimingData(
        )
        """

    def testReportingPurchaseTimingData(self):
        """Test ReportingPurchaseTimingData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
