# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_prediction_detail_response import ReportingPredictionDetailResponse

class TestReportingPredictionDetailResponse(unittest.TestCase):
    """ReportingPredictionDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPredictionDetailResponse:
        """Test ReportingPredictionDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPredictionDetailResponse`
        """
        model = ReportingPredictionDetailResponse()
        if include_optional:
            return ReportingPredictionDetailResponse(
                cached = True,
                error = '',
                prediction = neurograph.v1.models.reporting/prediction_detail.reporting.PredictionDetail(
                    account_id = '', 
                    assignment_date = '', 
                    client_id = '', 
                    persona_id = '', 
                    persona_name = '', 
                    prediction_id = '', 
                    raw_document = { }, ),
                query_time_ms = 56
            )
        else:
            return ReportingPredictionDetailResponse(
        )
        """

    def testReportingPredictionDetailResponse(self):
        """Test ReportingPredictionDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
