# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_affinity_meta import ReportingAffinityMeta

class TestReportingAffinityMeta(unittest.TestCase):
    """ReportingAffinityMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingAffinityMeta:
        """Test ReportingAffinityMeta
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingAffinityMeta`
        """
        model = ReportingAffinityMeta()
        if include_optional:
            return ReportingAffinityMeta(
                client_partition_key = '',
                client_uid = '',
                data_date = '',
                generated_at = '',
                organization_uid = '',
                persona_id = ''
            )
        else:
            return ReportingAffinityMeta(
        )
        """

    def testReportingAffinityMeta(self):
        """Test ReportingAffinityMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
