# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_daily_purchase_metrics import SignalDailyPurchaseMetrics

class TestSignalDailyPurchaseMetrics(unittest.TestCase):
    """SignalDailyPurchaseMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalDailyPurchaseMetrics:
        """Test SignalDailyPurchaseMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalDailyPurchaseMetrics`
        """
        model = SignalDailyPurchaseMetrics()
        if include_optional:
            return SignalDailyPurchaseMetrics(
                api_success_count = 56,
                api_success_rate = 1.337,
                avg_data_completeness = 1.337,
                avg_order_value = 1.337,
                var_date = '',
                new_customers = 56,
                predicted_revenue = 1.337,
                returning_customers = 56,
                total_purchases = 56,
                total_revenue = 1.337
            )
        else:
            return SignalDailyPurchaseMetrics(
        )
        """

    def testSignalDailyPurchaseMetrics(self):
        """Test SignalDailyPurchaseMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
